@@ -364,8 +364,21 @@ if ($db_users_result['status'] === '0') {
                 </h5>
             </div>
             <div class="card-body">
+                    <!-- Search Controls -->
+                    <div class="row mb-3">
+                        <div class="col-md-8">
+                            <div class="input-group">
+                                <span class="input-group-text"><i class="fa fa-search"></i></span>
+                                <input type="text" class="form-control" id="dbUserSearchInput" placeholder="Search database users...">
+                            </div>
+                        </div>
+                        <div class="col-md-4 text-end">
+                            <small class="text-muted" id="dbUserTableInfo"></small>
+                        </div>
+                    </div>
+
                     <div class="table-responsive">
-                        <table class="table table-striped table-hover">
+                        <table class="table table-striped table-hover" id="dbUsersTable">
                             <thead class="table-dark">
                                 <tr>
                                     <th>Username</th>
@@ -411,12 +424,34 @@ if ($db_users_result['status'] === '0') {
                             </tbody>
                         </table>
                     </div>
+
+                    <!-- Pagination Controls -->
+                    <div class="d-flex justify-content-center mt-3">
+                        <nav id="dbUserPagination"></nav>
+                    </div>
             </div>
         </div>
     </div>
 </div>
 <?php endif; ?>
 
+<script src="/js/table-pagination.js"></script>
+<script>
+// Initialize database users pagination
+document.addEventListener('DOMContentLoaded', function() {
+    const dbUsersTable = document.getElementById('dbUsersTable');
+    if (dbUsersTable) {
+        new TablePagination({
+            tableId: 'dbUsersTable',
+            searchId: 'dbUserSearchInput',
+            paginationId: 'dbUserPagination',
+            infoId: 'dbUserTableInfo',
+            itemsPerPage: 25
+        });
+    }
+});
+</script>
+
 <style>
 /* Fix form-text visibility on dark backgrounds */
 .form-text {
